var should = require('should');
var inspect = require('eyespect').inspector();
var add = require('../index');
describe('Add user to existing upload test', function () {
  var data;
  var userID = 'fooUserID';
  beforeEach(function () {
    data = {
      upload: {
        users: [],
        user_details: [],
        toObject: function () {
          return this;
        },
        save: function (cb) {
          cb();
        }
      },
      userID: userID
    };
  });
  it('should reject add requests where userID field is not set', function (done) {
    delete data.userID;
    add(data, function (err, reply) {
      should.exist(err);
      err.length.should.eql(1);
      var error = err[0];
      error.key.should.eql('userID');
      done();
    });
  });

  it('should reject add requests where upload field is not set', function (done) {
    delete data.upload;
    add(data, function (err, reply) {
      should.exist(err);
      err.length.should.eql(1);
      var error = err[0];
      error.key.should.eql('upload');
      done();
    });
  });

  it('should reject add requests where user is already in upload', function (done) {
    data.upload.users = [userID];
    add(data, function (err, reply) {
      should.not.exist(err);
      should.exist(reply);
      done();
    });
  });


  it('should add new user to upload', function (done) {
    add(data, function (err, upload) {
      should.not.exist(err);
      should.exist(upload);
      upload.user_details.length.should.eql(1);
      var details = upload.user_details[0];
      details.userID.should.eql(userID);
      done();
    });
  });
});